@@ -78,6 +78,8 @@ sed -i "15s/.*/    ${EGG}/" ${PROJECT_DIR}/live_base.cfg
 sed -i "15s/.*/    ${EGG}/" ${PROJECT_DIR}/qa_base.cfg
 sed -i s/skeleton/${APP}/g ${PROJECT_DIR}/*.cfg
 sed -i s/skeleton/${APP}/g ${APP_DIR}/*.py
+SECRET_KEY=`date +%s | sha256sum | head -c 56`
+sed -i "s/SECRET_KEY_PLACEHOLDER/${SECRET_KEY}/" ${APP_DIR}/settings.py
 sed -i s/skeleton/${APP}/g ${APP_DIR}/migrations/*.py
 if [ "$SITE" != "site" ];
 then
