@@ -6,7 +6,7 @@ TEMPLATE_DEBUG = DEBUG
 
 DATABASES = {
     'default': {
-        'ENGINE': 'django.db.backends.postgresql_psycopg2',
+        'ENGINE': 'django.contrib.gis.db.backends.postgis',
         'NAME': 'skeleton_live',
         'USER': 'skeleton_live',
         'PASSWORD': 'skeleton_live',
